/*
  Rhino test framework

   Copyright (C) 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

package org.RhinoTests.Reporter;

import java.util.List;
import java.util.Map;



/**
 * 
 * @author Pavel Tisnovsky
 */
public class TestResult {
    private int passed;
    private int failed;
    private int error;
    private String date;

    public TestResult() {
        this.setPassed(0);
        this.setFailed(0);
        this.setError(0);
        this.setDate(null);
    }

    /**
     * @param passed the passed to set
     */
    public void setPassed(int passed) {
        this.passed = passed;
    }

    /**
     * @return the passed
     */
    public int getPassed() {
        return this.passed;
    }

    /**
     * @param failed the failed to set
     */
    public void setFailed(int failed) {
        this.failed = failed;
    }

    /**
     * @return the failed
     */
    public int getFailed() {
        return this.failed;
    }

    /**
     * @param error the error to set
     */
    public void setError(int error) {
        this.error = error;
    }

    /**
     * @return the error
     */
    public int getError() {
        return this.error;
    }

    public static TestResult readSummary(Map<String, List<String>> testResultForDate) {
        TestResult testResult = new TestResult();
        for (Map.Entry<String, List<String>> testResultContent : testResultForDate.entrySet()) {
            for (String logLine : testResultContent.getValue()) {
                if (logLine.startsWith("SUMMARY: ")) {
                    final String strTotalTests = StringUtils.getSubstring(logLine, "total: ", "passed: ");
                    final String strPassedTests = StringUtils.getSubstring(logLine, "passed: ", "failed: ");
                    final String strFailedTests = StringUtils.getSubstring(logLine, "failed: ", "duration: ");
                    final int totalTests =Integer.parseInt(strTotalTests);
                    final int passedTests = Integer.parseInt(strPassedTests);
                    final int failedTests = Integer.parseInt(strFailedTests);
                    final int errorTests = totalTests - passedTests - failedTests;
                    testResult.setPassed(testResult.getPassed() + passedTests);
                    testResult.setFailed(testResult.getFailed() + failedTests);
                    testResult.setError(testResult.getError() + errorTests);
                }
            }
        }
        return testResult;
    }

    public String getDate() {
        return this.date;
    }

    public String getOsName() {
        return System.getProperty("os.name");
    }

    public String getOsVer() {
        return System.getProperty("os.version");
    }

    public String getOsArch() {
        return System.getProperty("os.arch");
    }

    public String getJavaVersion() {
        return System.getProperty("java.version");
    }

    public String getVmName() {
        return System.getProperty("java.vm.name");
    }

    public String getVmVersion() {
        return System.getProperty("java.vm.version");
    }

    public void setDate(String date) {
        this.date = date;
    }

}
